# print-clear

A tiny CLI tool used to print strings without ambiguity.

It does so by printing out its argument with the numbers, uppercase, lowercase, and special characters color coded.
Pass `--legend` to see the color code legend.
